/***************************************************************************
 *   Copyright (C) 2009 by Kai Dombrowe <just89@gmx.de>                    *
 *   Minor modifications by Andreas Fink <finkandreas@web.de>              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/
/// Qt
#include <QPainter>

/// own
#include "frame.h"


Frame::Frame(QGraphicsWidget *parent)
    : QGraphicsWidget(parent)
{
  _color = Plasma::Theme::defaultTheme()->color(Plasma::Theme::TextColor);
  _font = Plasma::Theme::defaultTheme()->font(Plasma::Theme::DesktopFont);

  _svg = new Plasma::FrameSvg(this);
  _svg->setImagePath("widgets/frame");
  _svg->setElementPrefix("plain");
  syncBorders();
  setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
}


Frame::~Frame()
{
  delete _svg;
}


void Frame::paint(QPainter *painter, const QStyleOptionGraphicsItem *, QWidget *)
{
  _svg->paintFrame(painter);
  painter->setPen(_color);
  painter->setFont(_font);
  painter->drawText(_svg->contentsRect(), _alignment, _text);
}


void Frame::setText(const QString &newText)
{
  if (_text == newText)
    return;

  _text = newText;
  syncBorders();
}


void Frame::updateAppearance(const QColor& newColor, const QFont& newFont, Shadow newShadow, Qt::Alignment alignment)
{
  if (_color == newColor && _font == newFont && _shadow == newShadow && _alignment == alignment)
    return;

  _shadow = newShadow;
  _color = newColor;
  _font = newFont;
  _alignment = alignment;

  switch (_shadow) {
        case Raised: _svg->setElementPrefix("raised"); break;
        case Sunken: _svg->setElementPrefix("sunken"); break;
        case Plain: _svg->setElementPrefix("plain"); break;
        default: _svg->setElementPrefix("plain"); break;
        }
  syncBorders();
}


void Frame::syncBorders()
{
  qreal left, top, right, bottom;
  _svg->getMargins(left, top, right, bottom);

  qreal textW(0);
  if (!_text.isEmpty()) {
    QFontMetricsF fm(_font);
    top += fm.height();
    textW = fm.width(_text);
  }

  setPreferredSize(textW, top+2);
  setMinimumHeight(top);

  if (size().width() < 1 || top < 1)
    return; // Invalid size

  setContentsMargins(left, top, right, bottom);
  _svg->resizeFrame(QSizeF(size().width(), top));
}


void Frame::resizeEvent(QGraphicsSceneResizeEvent *event)
{
  QGraphicsWidget::resizeEvent(event);
  syncBorders();
}


#include "frame.moc"
