/***************************************************************************
 *   Copyright (C) 2009 by Andreas Fink <finkandreas@web.de>               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/


#include "iconstack.h"

#include <QPainter>
#include <QGraphicsSceneMouseEvent>
#include <QDebug>

IconStack::IconStack(QGraphicsWidget* pParent)
    : QGraphicsWidget( pParent )
{
}


void IconStack::AddIcon( QPixmap p, QString click )
{
  int mh = minimumHeight();
  int mw = minimumWidth();
  mw += p.width() + 4;
  mh = mh > p.height() ? mh : p.height();
  setMinimumSize( mw, mh );
  m_IconList.append( qMakePair(p, click) );
  update();
}


void IconStack::paint(QPainter* p, const QStyleOptionGraphicsItem*, QWidget*)
{
  int w=0;
  for ( int i=0; i<m_IconList.size(); ++i ) {
    const QPixmap& pix = m_IconList[i].first;
    QRect r( w, 0, pix.width(), pix.height() );
    w += pix.width() + 4;
    p->drawPixmap( r, pix, QRect(QPoint(0, 0), pix.size()) );
  }
}


void IconStack::mousePressEvent(QGraphicsSceneMouseEvent* pEvent)
{
  int x = pEvent->pos().x();
  int w = 0;
  for ( int i=0; i<m_IconList.size(); ++i ) {
    QPixmap pix = m_IconList.at(i).first;
    if ( w < x && x < w+pix.width() )
      system(m_IconList.at(i).second.toUtf8().constData());
    w += pix.width() + 4;
  }
}
