/***************************************************************************
 *   Copyright (C) 2009 by Kai Dombrowe <just89@gmx.de>                    *
 *   Minor modifications by Andreas Fink <finkandreas@web.de>              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

///Qt
#include <QPainter>
#include <QGraphicsSceneMouseEvent>

///KDE
#include <Plasma/Theme>

/// own
#include "label.h"


Label::Label(const QPixmap& pixmap, QGraphicsWidget *parent)
    : QGraphicsWidget(parent),
    _pixmap(pixmap),
    _alignment(Qt::AlignLeft)
{
  setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
  _font = Plasma::Theme::defaultTheme()->font(Plasma::Theme::DesktopFont);
  _color = Plasma::Theme::defaultTheme()->color(Plasma::Theme::TextColor);
}


Label::~Label()
{
}


void Label::setText(const QString &newText)
{
  if (_text == newText)
    return;

  _text = newText;
  setPreferredSize( QFontMetrics(_font).boundingRect(0, 0, 10, 1, Qt::AlignLeft|Qt::AlignVCenter|Qt::TextExpandTabs, _text ).size()+QSize(2,0) );
  update();
}


void Label::paint(QPainter* paint, const QStyleOptionGraphicsItem*, QWidget*)
{
  paint->setPen(_color);
  paint->setFont(_font);

  if (!_pixmap.isNull()) {
    QRectF rect = contentsRect();

    paint->drawPixmap(rect, _pixmap, rect);

    rect.setLeft((_pixmap.width()+4));
    paint->drawText(rect, _alignment|Qt::AlignVCenter|Qt::TextExpandTabs, _text);
  } else {
    paint->drawText(contentsRect(), _alignment|Qt::AlignVCenter|Qt::TextExpandTabs, _text);
  }
}


void Label::updateAppearance(const QColor& newColor, const QFont& newFont, Qt::Alignment align)
{
  if (_color == newColor && _font == newFont)
    return;

  _color = newColor;
  _font = newFont;
  _alignment = align;
  setPreferredSize( QFontMetrics(_font).boundingRect(0, 0, 10, 1, Qt::AlignLeft|Qt::AlignVCenter|Qt::TextExpandTabs, _text).size()+QSize(2,0) );
}


void Label::mousePressEvent( QGraphicsSceneMouseEvent *e )
{
  bool bIconClicked = (!_pixmap.isNull() && e->pos().x() < _pixmap.width()+2);
  if (e->button() == Qt::LeftButton) {
    if ( bIconClicked && !m_IconClick.isEmpty() ) {
      system( m_IconClick.toUtf8().constData() );
    }
    else if ( !m_TextClick.isEmpty() ) {
      system( m_TextClick.toUtf8().constData() );
    }
  }
}

#include "label.moc"
