/***************************************************************************
 *   Copyright (C) 2009 by Andreas Fink <finkandreas@web.de>               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/


#ifndef SCRIPTPARSER_H
#define SCRIPTPARSER_H

#include <QThread>

#include "frame.h"
#include "structs.h"

// forward declarations
class Yasp;

class ScriptParser : public QThread
{
  Q_OBJECT

  public:
    ScriptParser( Yasp* pYasp );
    void ParseGuiElements();
    void ReparseRequested() { m_bReparseRequested = true; }

  protected:
    virtual void run();

    bool ParseKeyValue( const QString& sConfig, QString& sKey, QString& sValue, int& nStartIdx ) const;
    bool AddTitle( const QString& sConfig );
    bool AddValue( const QString& sConfig );
    bool AddSensor( const QString& sConfig );
    bool SetDefaults( const QString& sConfig );
    bool AddMeter( const QString& sConfig );
    bool AddSignalPlotter( const QString& sConfig );
    bool AddText( const QString& sConfig );
    bool AddIcons( const QString& sConfig );
    inline Qt::Alignment StringToAlignment( const QString& s );
    bool WaitForDependencies( const QStringList& Dependencies );
    inline QString& ReplaceFormatChars( QString& sIn ) const;

  private:
    Yasp* m_pYasp;
    int m_nInterval;
    QFont m_TitleFont, m_ValueFont;
    QColor m_TitleColor, m_ValueColor;
    Qt::Alignment m_TitleAlignment, m_ValueAlignment;
    Frame::Shadow m_TitleShadow;
    int m_Row;
    QStringList m_RegisteredSensors;
    QStringList m_GuiElements;
    bool m_bParsingSensors;
    bool m_bReparseRequested;

  signals:
    void EngineSensorAdded( const SourceIntervalPair&, const SensorCmdPair& );
    void ProgramSensorAdded( const SensorCmdPair&, int );
    void LabelAdded( const SensorLabelPair&, int );
    void MeterAdded( const SensorMeterPair&, int );
    void PlotterAdded( const SensorPlotterPair&, int );
    void TextAdded( const SensorTextPair&, int );
};

#endif // SCRIPTPARSER_H
